#ifndef TEUCHOSCORE_CONFIG_H_
#define TEUCHOSCORE_CONFIG_H_

#define HAVE_TEUCHOSCORE_KOKKOSCORE

#define HAVE_TEUCHOSCORE_CXX11

#define HAVE_TEUCHOSCORE_BOOST

#define HAVE_TEUCHOSCORE_BOOST_IS_POLYMORPHIC

/* #undef HAVE_TEUCHOSCORE_QT */

/* Deprecated */
/* #undef HAVE_TEUCHOSCORE_QD */

/* #undef HAVE_TEUCHOSCORE_QUADMATH */

/* Deprecated */
/* #undef HAVE_TEUCHOSCORE_ARPREC */

#define HAVE_TEUCHOSCORE_YAML_CPP 0
/* ToDo: Move the TeuchosCore parts from Teuchos_config.h.in to here and git
 * rid of Teuchos_config.h.in */

#endif // TEUCHOSCORE_CONFIG_H_
